@@ -1,7 +1,13 @@
 # -*- coding: utf-8 -*-
 from __future__ import print_function
+from distutils.spawn import find_executable
+from functools import lru_cache, wraps
+from tempfile import _TemporaryFileWrapper as TemporaryFileWrapperBase
+
+cache = lambda function: lru_cache(maxsize=128, typed=True)(function)
 
 import abc
+import clu.abstract
 import collections
 import collections.abc
 import contextlib
@@ -11,22 +17,17 @@ import shutil
 import sys
 import weakref
 import zipfile
-    
-from distutils.spawn import find_executable
-from functools import wraps
-from tempfile import _TemporaryFileWrapper as TemporaryFileWrapperBase
 
 from clu.constants.consts import λ, DELETE_FLAG, ENCODING, PATH, SCRIPT_PATH
 from clu.constants.exceptions import ExecutionError, FilesystemError
-from clu.constants.polyfills import lru_cache, scandir, walk
-from clu.abstract import ValueDescriptor
 from clu.dicts import OrderedItemsView, OrderedKeysView, OrderedValuesView
 from clu.predicates import attr, allattrs, anyof, uniquify
 from clu.repr import stringify
 from clu.sanitizer import utf8_encode
 from clu.typology import isnotpath, isvalidpath
 from clu.fs.misc import differentfile, filesize, gethomedir, masked_permissions
-from clu.fs.misc import re_searcher, suffix_searcher, swapext, u8str, extension
+from clu.fs.misc import re_searcher, suffix_searcher, re_excluder
+from clu.fs.misc import swapext, u8str, extension
 from clu.exporting import Exporter, path_to_dotpath
 
 exporter = Exporter(path=__file__)
@@ -83,8 +84,7 @@ which.pathvar = PATH
 def back_tick(command,  as_str=True,
                        ret_err=False,
                      raise_err=None, **kwargs):
-    f""" Run command `command`, return stdout -- or (stdout, stderr) if `ret_err`.
-        Roughly equivalent to ``check_output`` in Python 2.7.
+    f""" Run command `command`, returning stdout – or (stdout, stderr) if `ret_err`.
         
         Parameters
         ----------
@@ -94,19 +94,19 @@ def back_tick(command,  as_str=True,
             ["ls", "-la"]).
         as_str : bool, optional
             Whether or not the values returned from ``proc.communicate()`` should
-            be unicode-decoded as bytestrings (using the specified encoding, which
-            defaults to Latin-1) before `back_tick(…)` returns. Default is True.
+            be unicode-decoded from bytestrings (using the specified encoding, which
+            defaults to “{ENCODING}”) to strings before `back_tick(…)` returns.
+            Default is True.
         ret_err : bool, optional
             If True, the return value is (stdout, stderr). If False, it is stdout.
             In either case `stdout` and `stderr` are strings containing output
             from the commands’ execution. Default is False.
         raise_err : None or bool, optional
-            If True, raise clu.fs.filesystem.ExecutionError when calling the
+            If True, raise a ‘clu.fs.filesystem.ExecutionError’ when calling the
                      function results in a non-zero return code.
             If None, it is set to True if `ret_err` is False,
                                   False if `ret_err` is True.
-            Default is None (exception-raising behavior depends on the `ret_err`
-            value).
+            Default is None (exception-raising depends on the value of `ret_err`).
         encoding : str, optional
             The name of the encoding to use when decoding the command output per
             the `as_str` value. Default is “{ENCODING}”.
@@ -118,7 +118,7 @@ def back_tick(command,  as_str=True,
             Default is False.
         timeout : int, optional
             Number of seconds to wait for the executed command to complete before
-            forcibly killing the subprocess. Default is 60.
+            forcibly killing its subprocess. Default is {DEFAULT_TIMEOUT} seconds.
         
         Returns
         -------
@@ -130,10 +130,8 @@ def back_tick(command,  as_str=True,
         
         Raises
         ------
-        A `clu.fs.filesystem.ExecutionError` will raise if the
-        executed command returns with any non-zero exit status, and `raise_err`
-        is set to True.
-        
+        A ‘clu.fs.filesystem.ExecutionError’ will raise if the executed command
+        returns with any non-zero exit status, and `raise_err` is set to True.
     """
     # Step 1: Prepare for battle:
     import subprocess, shlex
@@ -159,12 +157,12 @@ def back_tick(command,  as_str=True,
     try:
         output, errors = process.communicate(timeout=timeout)
     except subprocess.TimeoutExpired:
-        process.kill()
+        process.terminate()
         output, errors = process.communicate(timeout=None)
     returncode = process.returncode
     # Step 3: Analyze the return code:
     if returncode is None:
-        process.terminate()
+        process.kill()
         raise ExecutionError(f'`{command_str}` terminated without exiting cleanly')
     if raise_err and returncode != 0:
         error_str = u8str(errors).strip()
@@ -209,7 +207,7 @@ def rm_rf(path):
             os.unlink(path)
         elif os.path.isdir(path):
             subdirs = []
-            for root, dirs, files in walk(path, followlinks=True):
+            for root, dirs, files in os.walk(path, followlinks=True):
                 for tf in files:
                     os.unlink(os.path.join(root, tf))
                 subdirs.extend((os.path.join(root, td) for td in dirs))
@@ -290,7 +288,7 @@ class TypeLocker(abc.ABCMeta):
         """
         # Fill in the “types” attribute to prevent the metaclass’
         # registry dict from leaking into subtypes:
-        attributes['types']         = ValueDescriptor(tuple())
+        attributes['types']         = clu.abstract.ValueDescriptor(tuple())
         
         # Always replace the “directory” method anew:
         directory = lambda pth=None: metacls.types['Directory'](pth=pth)
@@ -336,8 +334,6 @@ class TemporaryFileWrapper(TemporaryFileWrapperBase,
     def __fspath__(self):
         return self.name
 
-cache = lru_cache(maxsize=128, typed=True)
-
 @cache
 def TemporaryNamedFile(temppath, mode='wb',
                                  delete=True,
@@ -913,9 +909,10 @@ class Directory(collections.abc.Hashable,
             Specify an optional “suffix” parameter to filter the list by a
             particular file suffix (leading dots unnecessary but unharmful).
         """
-        return tuple(filter(suffix_searcher(suffix),
-                    (direntry.name for direntry in filter(non_dotfile_matcher,
-                                                  scandir(self.realpath(source))))))
+        with os.scandir(self.realpath(source)) as iterscan:
+            return tuple(filter(suffix_searcher(suffix),
+                        (direntry.name for direntry in filter(non_dotfile_matcher,
+                                                              iterscan))))
     
     def ls_la(self, suffix=None, source=None):
         """ List all files, including files whose name starts with a dot.
@@ -931,8 +928,9 @@ class Directory(collections.abc.Hashable,
             commands I ever learned, and it reads better than `ls_a()` which
             I think looks awkward and goofy.)
         """
-        return tuple(filter(suffix_searcher(suffix),
-                    (direntry.name for direntry in scandir(self.realpath(source)))))
+        with os.scandir(self.realpath(source)) as iterscan:
+            return tuple(filter(suffix_searcher(suffix),
+                        (direntry.name for direntry in iterscan)))
     
     def subpath(self, subpath, source=None, requisite=False):
         """ Returns the path to a subpath of the instances’ target path. """
@@ -968,14 +966,12 @@ class Directory(collections.abc.Hashable,
         return self
     
     def walk(self, followlinks=True):
-        """ Sugar for calling X.walk(self.name), where X is either
-            `scandir` (in the case of python 2.7) or `os` (for
-            python 3 and thereafter).
+        """ Sugar for calling os.walk(self.name)
             
             Note that the “followlinks” default here is True, whereas
             the underlying functions default to False for that argument.
         """
-        return walk(self.name, followlinks=followlinks)
+        return os.walk(self.name, followlinks=followlinks)
     
     def parent(self):
         """ Sugar for `os.path.abspath(os.path.join(self.name, os.pardir))`
@@ -1158,14 +1154,13 @@ class Directory(collections.abc.Hashable,
             matching the “suffix” string, and not matching any of the
             “excludes” strings.
         """
-        ex = '|'.join(re.escape(exclude) for exclude in excludes)
-        exclude = re.compile(f"(?P<XXX>{ex})", re.IGNORECASE)
-        excluder = lambda filename: not bool(exclude.search(filename))
+        excluder = re_excluder(excludes)
         searcher = suffix_searcher(suffix)
         dotpaths = []
+        target = self.subdirectory(subdir or os.path.curdir, source)
         # Use a call to “os.walk(…)” directly to allow modification of
         # the “dirs” list in-place:
-        for root, dirs, files in os.walk(self.subdirectory(subdir, source)):
+        for root, dirs, files in os.walk(target):
             dirs[:] = list(filter(excluder, dirs))
             filenames = filter(excluder,
                         filter(searcher, files))
@@ -1181,9 +1176,7 @@ class Directory(collections.abc.Hashable,
             file suffixes for all files found in the given subdirectory,
             excluding anything matching any of the “excludes” strings
         """
-        ex = '|'.join(re.escape(exclude) for exclude in excludes)
-        exclude = re.compile(f"(?P<XXX>{ex})", re.IGNORECASE)
-        excluder = lambda filename: not bool(exclude.search(filename))
+        excluder = re_excluder(excludes)
         searcher = re_searcher(re.escape(os.path.extsep))
         suffixes = collections.Counter()
         target = self.subdirectory(subdir or os.path.curdir, source)
@@ -1191,7 +1184,7 @@ class Directory(collections.abc.Hashable,
         # the “dirs” list in-place:
         for root, dirs, files in os.walk(target):
             dirs[:] = list(filter(excluder, dirs))
-            for ext in filter(None, 
+            for ext in filter(None,
                        map(lambda filename: extension(filename).lower(),
                        filter(excluder,
                        filter(searcher, files)))):
@@ -1237,14 +1230,14 @@ class Directory(collections.abc.Hashable,
     
     def __iter__(self):
         out = self.exists \
-              and (k.name for k in scandir(
+              and (k.name for k in os.scandir(
                                    os.path.realpath(self.name))) \
                or iter(tuple())
         yield from out
     
     def __reversed__(self):
         out = self.exists \
-              and (k.name for k in reversed(scandir(
+              and (k.name for k in reversed(os.scandir(
                                    os.path.realpath(self.name)))) \
                or iter(tuple())
         yield from out
