@@ -1,7 +1,13 @@
 # -*- coding: utf-8 -*-
 from __future__ import print_function
+from functools import wraps
 
-from clu.constants.consts import BASEPATH, DEBUG, QUALIFIER, NoDefault
+import importlib
+import importlib.machinery
+import inspect
+import pickle
+
+from clu.constants.consts import λ, φ, BASEPATH, DEBUG, QUALIFIER, NoDefault
 from clu.exporting import (path_to_dotpath, determine_name,
                                             search_for_name,
                                             search_for_module)
@@ -15,8 +21,6 @@ def determine_module(thing, name=None):
     """ Private module function to find the module of a thing,
         using “pickle.whichmodule(…)”
     """
-    import pickle
-    
     if name is not None:
         return name
     if thing is None:
@@ -106,6 +110,14 @@ def moduleof(thing, default=NoDefault):
 
 isbuiltin = lambda thing: moduleof(thing) == 'builtins'
 
+suffix = lambda filename: QUALIFIER in filename \
+            and filename.rpartition(QUALIFIER)[-1] \
+             or ''
+
+EXTENSION_SUFFIXES = tuple(suffix.lstrip(QUALIFIER) \
+                       for suffix \
+                        in importlib.machinery.EXTENSION_SUFFIXES)
+
 @export
 def isnativemodule(module):
     """ isnativemodule(thing) → boolean predicate, True if `module`
@@ -114,7 +126,6 @@ def isnativemodule(module):
         Q.v. this fine StackOverflow answer on this subject:
             https://stackoverflow.com/a/39304199/298171
     """
-    import importlib.machinery, inspect, os
     from clu.predicates import getpyattr
     from clu.typology import ismodule
     
@@ -128,17 +139,15 @@ def isnativemodule(module):
         return True
     
     # Step three: in leu of either of those indicators,
-    # check the module path:
-    pth = inspect.getfile(module)
-    ext = os.path.splitext(pth)[1]
-    return ext in importlib.machinery.EXTENSION_SUFFIXES
+    # check the module path’s file suffix:
+    ext = suffix(inspect.getfile(module))
+    return ext in EXTENSION_SUFFIXES
 
 @export
 def isnative(thing):
     """ isnative(thing) → boolean predicate, True if `thing`
         comes from a native-compiled (“extension”) module.
     """
-    import importlib
     module = moduleof(thing)
     if module == 'builtins':
         return False
@@ -181,16 +190,14 @@ def dotpath_split(dotpath):
     """
     if dotpath is None:
         return None, None
-    head = dotpath.split(QUALIFIER)[-1]
-    tail = dotpath.replace(f"{QUALIFIER}{head}", '')
-    return head, tail != head and tail or None
+    tail, _, head = str(dotpath).rpartition(QUALIFIER)
+    return head, tail or None
 
 @export
 def qualified_import(qualified):
     """ Import a qualified thing-name.
         e.g. 'instakit.processors.halftone.FloydSteinberg'
     """
-    import importlib
     if QUALIFIER not in qualified:
         raise ValueError(f"qualified name required (got {qualified})")
     head, tail = dotpath_split(qualified)
@@ -212,8 +219,8 @@ def qualified_name(thing):
     """ Get a qualified thing-name for a thing.
         e.g. 'instakit.processors.halftone.FloydSteinberg'
     """
-    mod_name, cls_name = qualified_name_tuple(thing)
-    qualname = dotpath_join(mod_name, cls_name)
+    module_name, thing_name = qualified_name_tuple(thing)
+    qualname = dotpath_join(module_name, thing_name)
     if DEBUG:
         print(f"Qualified Name: {qualname}")
     return qualname
@@ -239,6 +246,54 @@ def path_to_prefix(path, sep='-', end='-', relative_to=BASEPATH):
                              sep=sep,
                              end=end)
 
+@export
+class rename(object):
+    
+    """ Function-rename decorator. Use like so:
+        
+            @rename(named='yodogg')
+            def YoDogg(*args):
+                ...
+        
+        … or:
+            
+            yodogg = lambda *args: ...
+            yodogg = rename()(yodogg) # awkward syntax, I know
+        
+    """
+    
+    def __init__(self, named=None,
+                        path=None,
+                     dotpath=None):
+        """ Initialize a @rename object decorator. All parameters are optional. """
+        self.named = named
+        self.dotpath = dotpath or path_to_dotpath(path,
+                                                  relative_to=BASEPATH)
+    
+    def assign_name(self, function, name=None):
+        """ Assign the function’s new name. Returns the mutated function. """
+        named = determine_name(function, name=name or self.named)
+        dname = getattr(function, '__name__')
+        if dname in (λ, φ):
+            if named in (λ, φ):
+                named = search_for_name(function)
+            if named is None:
+                raise NameError(str(id(function)))
+            function.__name__ = function.__qualname__ = named
+            function.__lambda_name__ = dname # To recall the lambda’s genesis
+            if dname == φ and self.dotpath is not None:
+                function.__module__ = str(self.dotpath) # Reset __module__ for phi-types
+        return function
+    
+    def __call__(self, f):
+        function = self.assign_name(f)
+        if not inspect.isfunction(function):
+            return function
+        @wraps(function)
+        def renamed(*args, **kwargs):
+            return function(*args, **kwargs)
+        return function
+
 @export
 def split_abbreviations(s):
     """ Split a string into a tuple of its unique constituents,
@@ -279,6 +334,7 @@ def split_abbreviations(s):
     return tuple(abbreviations)
 
 export(isbuiltin,      name='isbuiltin',  doc="isbuiltin(thing) → boolean predicate, True if `thing` is a builtin function/method/class")
+export(suffix,         name='suffix',     doc="suffix(path) → return the suffix ≠ the file extension ≠ for a file pathname")
 
 # Assign the modules’ `__all__` and `__dir__` using the exporter:
 __all__, __dir__ = exporter.all_and_dir()
